@@ -1,4 +1,4 @@
-#[derive(PartialEq, Debug)]
+#[derive(Clone, PartialEq, Debug)]
 pub enum Action {
     Report,
     Filter,
@@ -8,9 +8,9 @@ pub enum Action {
     Log,
     Modify,
     HelpPopup,
-    Error,
     ContextMenu,
     Jump,
     DeletePrompt,
     DonePrompt,
+    Error,
 }
